from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="briq",
    version="0.1.1.dev1",
    author="Briq Team",
    author_email="sms@briq.tz",
    description="Python client for the Briq messaging platform API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/BRIQ-BLOCK/BriqPythonSdk",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
    install_requires=[
        "requests>=2.25.0",
        "python-dotenv>=0.15.0",
    ],
)
